@@ -46,9 +46,10 @@ void separns_replace_sep(const char *base, char **ns, char **name, char r);
    namespace */
 char * make_pre_macro(const char *base,const  char *pre);
 
-/* get a name usable for a cast from a GTK+ type (without GTK_TYPE_)*/
+/* get a name usable for a cast from a GObject (without G_TYPE_)*/
 const char * get_cast (const char *type, gboolean simple_only);
 Type * get_tree_type (const char *type, gboolean simple_only);
+char * get_type (const Type *t, gboolean postfix_to_stars);
 
 enum {
 	SPECIAL_2POINTER,
